@@ -91,7 +91,7 @@ class mysqlUtil:
                 ftype)
         else:
             ftype = ".mp4"
-            'select id,url,fdesc,fsize,duration,ftype,uptime,pid from sftp_files where ftype="{}" order by uptime desc limit 100'.format(
+            sql ='select id,url,fdesc,fsize,duration,ftype,uptime,pid from sftp_files where ftype="{}" order by uptime desc limit 100'.format(
                 ftype)
         connection = self.engine.connect()
         df = pd.read_sql(sql, con=connection)
@@ -111,7 +111,7 @@ class mysqlUtil:
                 pid)
         else:
             pid = "p023101".lower()
-            'select id,url,fdesc,fsize,duration,ftype,uptime,pid from sftp_files where pid="{}" order by uptime desc limit 100'.format(
+            sql ='select id,url,fdesc,fsize,duration,ftype,uptime,pid from sftp_files where pid="{}" order by uptime desc limit 100'.format(
                 pid)
         connection = self.engine.connect()
         df = pd.read_sql(sql=sql,con=connection)
